@@ -1,7 +1,7 @@
 #![windows_subsystem = "windows"]
 
 use nxui::graphic::icon::Icon;
-use nxui::natives_and_messaging::{AWS_NONE, WS_NORMAL};
+use nxui::natives_and_messaging::*;
 use nxui::window::{AdvancedOptions, Application, Attributes, Frame};
 
 fn main() {
@@ -40,7 +40,7 @@ impl Application for IconWindow {
     }
 
     fn advanced_options(&self) -> AdvancedOptions {
-        AdvancedOptions::new(AWS_NONE)
+        AdvancedOptions::new(AWS_NONE,WC_DEFAULT)
     }
 
     fn ui(&self, frame: &Frame) {
