@@ -1,5 +1,5 @@
 use nxui::graphic::icon::Icon;
-use nxui::natives_and_messaging::{AWS_UTILITY, WS_NORMAL};
+use nxui::natives_and_messaging::*;
 use nxui::window::{AdvancedOptions, Application, Attributes, Frame};
 
 fn main() {
@@ -38,7 +38,7 @@ impl Application for UtilityApplication {
     }
 
     fn advanced_options(&self) -> AdvancedOptions {
-        AdvancedOptions::new(AWS_UTILITY, Icon::default().get_icon())
+        AdvancedOptions::new(AWS_UTILITY, WC_DEFAULT)
     }
 
     fn ui(&self, frame: &Frame) {
