@@ -11,11 +11,15 @@ pub struct Storage {
 impl Storage {
     /// Create a new Storage
     /// It will also create a directory based on the AppDirs argument.
-    pub fn new(app_dirs: AppDirs) -> Self {
+    pub fn new(app_dirs:  AppDirs) -> Self {
         Self { app_dirs }
     }
 
-    pub fn create_app_dir(&self) {
+    #[no_mangle] pub extern "C" fn new_storage(app_dirs:  AppDirs) -> Self {
+        Self { app_dirs }
+    }
+
+    #[no_mangle] pub extern "C" fn create_app_dir(&self) {
         match self.app_dirs.config_dir.exists() {
             true => {}
             false => {
@@ -58,22 +62,22 @@ impl Storage {
     }
 
     /// Returns the cache_dir
-    pub fn get_cache_dir(self) -> PathBuf {
+    #[no_mangle] pub extern "C" fn get_cache_dir(self) -> PathBuf {
         self.app_dirs.cache_dir
     }
 
     /// Returns the config_dir
-    pub fn get_config_dir(self) -> PathBuf {
+    #[no_mangle] pub extern "C" fn get_config_dir(self) -> PathBuf {
         self.app_dirs.config_dir
     }
 
     /// Returns the state_dir
-    pub fn get_state_dir(self) -> PathBuf {
+    #[no_mangle] pub extern "C" fn get_state_dir(self) -> PathBuf {
         self.app_dirs.state_dir
     }
 
     /// Returns the data_dir
-    pub fn get_data_dir(self) -> PathBuf {
+    #[no_mangle] pub extern "C" fn get_data_dir(self) -> PathBuf {
         self.app_dirs.data_dir
     }
 }
