@@ -1,8 +1,22 @@
 //! Constants for communicating with the OS about dialog styles, etc.
 
+#[cfg(windows)]
+use windows_sys::Win32::UI::WindowsAndMessaging::*;
+
 pub type FileChooserStyle = i32;
 pub type WidgetStyle<'a> = &'a str;
 
+// Default Constants
+#[cfg(windows)]
+pub const DF_WINDOW_POS: i32 = windows_sys::Win32::UI::WindowsAndMessaging::CW_USEDEFAULT;
+#[cfg(windows)]
+pub const DF_WINDOW_SIZE: i32 = windows_sys::Win32::UI::WindowsAndMessaging::CW_USEDEFAULT;
+#[cfg(unix)]
+pub const DF_WINDOW_POS: i32 = 400;
+#[cfg(unix)]
+pub const DF_WINDOW_SIZE: i32 = 500;
+
+
 // Dialog Styles
 
 #[cfg(windows)]
@@ -109,6 +123,10 @@ pub const WS_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE =
 /// A window with only a close button
 pub const WS_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE =
     windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
+#[cfg(windows)]
+pub const WS_DISABLE_MAXIMIZE:windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = WS_CAPTION|WS_SYSMENU|WS_THICKFRAME|WS_MINIMIZEBOX;
+#[cfg(windows)]
+pub const WS_DISABLE_MAXIMIZE_MINIMIZE:windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = WS_CAPTION|WS_SYSMENU|WS_THICKFRAME;
 
 #[cfg(unix)]
 /// Standard window
@@ -143,6 +161,23 @@ pub const FC_NEW_EXPLORER: winapi::shared::minwindef::DWORD = winapi::um::commdl
 #[cfg(windows)]
 pub const FC_ENABLE_HELP: winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_SHOWHELP;
 
+#[cfg(windows)]
+pub const WC_NULL: i32 = 0;
+#[cfg(windows)]
+pub const WC_GRAY: i32 = 22;
+#[cfg(windows)]
+pub const WC_DEFAULT: i32 = 5;
+#[cfg(windows)]
+pub const WC_BLUE: i32 = 14;
+#[cfg(windows)]
+pub const WC_LIGHT_GRAY: i32 = 11;
+#[cfg(windows)]
+pub const WC_WHITE: i32 = 6;
+#[cfg(windows)]
+pub const WC_LIGHT_BLUE: i32 = 3;
+#[cfg(windows)]
+pub const WC_BLACK: i32 = 2;
+
 #[deprecated(since = "0.15.2", note = "Please use the respective widget structure")]
 pub const WT_BUTTON: WidgetStyle = "BUTTON\0";
 #[deprecated(since = "0.15.2", note = "Please use the respective widget structure")]
