@@ -1,3 +1,4 @@
+
 use crate::io::get_app_dirs;
 use crate::io::storage::Storage;
 use crate::messagebox::MessageBox;
@@ -6,7 +7,7 @@ use crate::window::{Application, Frame};
 
 #[cfg(windows)]
 /// Run nxui::window::Application
-pub fn create_new_app(application: Box<dyn Application>) {
+#[no_mangle] pub extern "C" fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
@@ -46,7 +47,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
     unsafe {
         let instance = GetModuleHandleA(std::ptr::null_mut());
         debug_assert!(instance != 0);
-
+        use windows_sys::Win32::Graphics::Gdi::HBRUSH;
         let wc = WNDCLASSA {
             hCursor: LoadCursorW(0, IDC_ARROW),
             hInstance: instance,
@@ -56,7 +57,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
             cbClsExtra: 0,
             cbWndExtra: 0,
             hIcon: 0,
-            hbrBackground: 5,
+            hbrBackground: advanced_option.get_background_color() as HBRUSH,
             lpszMenuName: std::ptr::null_mut(),
         };
 
@@ -64,7 +65,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
         debug_assert!(atom != 0);
         let win = CreateWindowExA(
             advanced_option.get_style(),
-            "window".as_ptr(),
+            b"window".as_ptr(),
             format!("{}\0", attributes.title).as_ptr(),
             attributes.style | WS_VISIBLE,
             attributes.x,
@@ -101,7 +102,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
 
 #[cfg(unix)]
 /// Run nxui::window::Application
-pub fn create_new_app(application: Box<dyn Application>) {
+#[no_mangle] pub extern "C" fn create_new_app(application: Box<dyn Application>) {
     // Get window title
     let app_name = application.app_name();
     // Get attributes
