@@ -1,9 +1,11 @@
-use std::iter::once;
+//! Only MenuItem widget can be placed.
+
 use crate::widget::menuitem::MenuItem;
+use std::iter::once;
 
 #[cfg(windows)]
 pub struct MenuBar {
-    menu: windows_sys::Win32::UI::WindowsAndMessaging::HMENU
+    menu: windows_sys::Win32::UI::WindowsAndMessaging::HMENU,
 }
 
 #[cfg(windows)]
@@ -12,16 +14,23 @@ impl MenuBar {
         use windows_sys::Win32::UI::WindowsAndMessaging::CreateMenu;
         unsafe {
             let menu = CreateMenu();
-            Self {
-                menu,
-            }
+            Self { menu }
         }
     }
 
-    pub fn add_menu(&self,item: MenuItem) {
+    pub fn add_menu(&self, item: MenuItem) {
         use windows_sys::Win32::UI::WindowsAndMessaging::*;
         unsafe {
-            AppendMenuW(self.menu, MF_POPUP|MFT_STRING, item.get_menu().try_into().unwrap(), item.get_title().encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr());
+            AppendMenuW(
+                self.menu,
+                MF_POPUP | MFT_STRING,
+                item.get_menu().try_into().unwrap(),
+                item.get_title()
+                    .encode_utf16()
+                    .chain(once(0))
+                    .collect::<Vec<u16>>()
+                    .as_mut_ptr(),
+            );
         }
     }
 
@@ -32,7 +41,7 @@ impl MenuBar {
 
 #[cfg(unix)]
 pub struct MenuBar {
-    menu: gtk::gio::Menu
+    menu: gtk::gio::Menu,
 }
 
 #[cfg(unix)]
@@ -40,12 +49,10 @@ impl MenuBar {
     pub fn new() -> Self {
         use gtk::gio::Menu;
         let menu = Menu::new();
-        Self {
-            menu
-        }
+        Self { menu }
     }
 
-    pub fn add_menu(&self,item: MenuItem) {
+    pub fn add_menu(&self, item: MenuItem) {
         use gtk::prelude::*;
         self.menu.append_item(&item.get_menu());
     }
@@ -53,4 +60,4 @@ impl MenuBar {
     pub fn get_menu(self) -> gtk::gio::Menu {
         self.menu
     }
-}
\ No newline at end of file
+}
