@@ -1,29 +1,21 @@
 //! Vertical widget layout.
 
 #[cfg(windows)]
-pub struct VBox {
-
-}
+pub struct VBox {}
 
 #[cfg(windows)]
 impl VBox {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
 #[cfg(unix)]
-pub struct VBox {
-
-}
+pub struct VBox {}
 
 #[cfg(unix)]
 impl VBox {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
-}
\ No newline at end of file
+}
