@@ -1,18 +1,23 @@
 //! Dialog type window.
 
-use crate::window::{Attributes, Frame};
+use crate::window::{AdvancedOptions, Attributes, Frame};
 
 pub trait Dialog {
     fn attributes(&self) -> Attributes;
 
     fn frame(&self) -> Frame;
 
+    fn advanced_options(&self) -> AdvancedOptions {
+        AdvancedOptions::default()
+    }
+
     fn ui(&self, frame: Frame);
 }
 
 #[cfg(windows)]
 pub fn create_dialog(dialog: Box<dyn Dialog>) {
     let attributes = dialog.attributes();
+    let advanced_options = dialog.advanced_options();
     let frame = dialog.frame();
     use windows_sys::{
         Win32::Foundation::*, Win32::System::LibraryLoader::GetModuleHandleA,
