@@ -10,7 +10,7 @@ pub mod dialog;
 #[derive(Clone)]
 pub struct Frame {
     /// Window body
-    handle: windows_sys::Win32::Foundation::HWND,
+    handle: windows_sys::Win32::Foundation::HWND
 }
 
 #[cfg(windows)]
@@ -90,7 +90,7 @@ impl Frame {
     /// **Warning: This method is unstable.**
     pub fn set_size(&self, width: i32, height: i32) {
         use windows_sys::Win32::Foundation::RECT;
-        use windows_sys::Win32::UI::WindowsAndMessaging::*;
+        use windows_sys::Win32::UI::WindowsAndMessaging::{SetWindowPos,GetWindowRect,ShowWindow,SW_SHOWDEFAULT};
         unsafe {
             let rect = &mut RECT {
                 left: 0,
@@ -125,6 +125,20 @@ impl Frame {
             );
         }
     }
+
+    pub fn set_blur(&self) {
+        use windows_sys::Win32::Graphics::Dwm::*;
+        use windows_sys::Win32::Foundation::BOOL;
+        unsafe {
+            let bb = &mut DWM_BLURBEHIND {
+                dwFlags: DWM_BB_ENABLE,
+                fEnable: BOOL::from(true),
+                hRgnBlur: 0,
+                fTransitionOnMaximized: 0
+            };
+            DwmEnableBlurBehindWindow(self.handle,bb);
+        }
+    }
 }
 
 #[cfg(windows)]
@@ -171,25 +185,30 @@ impl Attributes {
 #[cfg(windows)]
 pub struct AdvancedOptions {
     advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE,
+    background_color: i32
 }
 
 #[cfg(windows)]
 impl AdvancedOptions {
     pub fn new(
-        advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE,
+        advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE,background_color: i32
     ) -> Self {
-        Self { advanced_style }
+        Self { advanced_style,background_color }
     }
 
     pub fn get_style(&self) -> windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE {
         self.advanced_style
     }
+
+    pub fn get_background_color(&self) -> i32 {
+        self.background_color
+    }
 }
 
 #[cfg(windows)]
 impl Default for AdvancedOptions {
     fn default() -> Self {
-        Self { advanced_style: 0 }
+        Self { advanced_style: 0, background_color: 5 }
     }
 }
 
